@@ -10,6 +10,8 @@ from thunder.regression.regress import MeanRegressionModel, LinearRegressionMode
 from thunder.clustering.kmeans import KMeans, KMeansModel
 from thunder.regression.tuning import TuningModel
 from thunder.regression.tuning import GaussianTuningModel, CircularTuningModel
+from thunder.imgprocessing.registration import Registration, RegistrationModel
+from thunder.imgprocessing.regmethods.crosscorr import CrossCorr, PlanarCrossCorr
 
 # data types
 from thunder.rdds.series import Series
@@ -21,7 +23,6 @@ from thunder.rdds.images import Images
 # utilities
 from thunder.viz.colorize import Colorize
 from thunder.utils.datasets import DataSets
-from thunder.utils.export import export
 from thunder.utils.context import ThunderContext
 
-__version__ = "0.4.1"
+__version__ = "0.5.0"
