@@ -2,7 +2,7 @@
 Class for mass-univariate classification
 """
 
-from numpy import in1d, zeros, array, size, float64
+from numpy import in1d, zeros, array, size, float64, asarray
 
 from thunder.rdds.series import Series
 
@@ -40,21 +40,22 @@ class MassUnivariateClassifier(object):
     `samples` : array
         Which sample does each time point belong to
 
-    `sampleids` : list
+    `sampleIds` : list
         Unique samples
 
     `nsamples` : int
         Number of samples
     """
 
-    def __init__(self, paramfile):
+    def __init__(self, paramFile):
         from scipy.io import loadmat
-        if type(paramfile) is str:
-            params = loadmat(paramfile, squeeze_me=True)
-        elif type(paramfile) is dict:
-            params = paramfile
+        if type(paramFile) is str:
+            params = loadmat(paramFile, squeeze_me=True)
+        elif type(paramFile) is dict:
+            params = paramFile
         else:
-            raise TypeError("Parameters for classification must be provided as string with file location, or dictionary")
+            raise TypeError("Parameters for classification must be provided as string with file location," +
+                            " or dictionary")
 
         self.labels = params['labels']
 
@@ -62,20 +63,22 @@ class MassUnivariateClassifier(object):
             self.features = params['features']
             self.nfeatures = len(list(set(self.features.flatten())))
             self.samples = params['samples']
-            self.sampleids = list(set(self.samples.flatten()))
-            self.nsamples = len(self.sampleids)
+            self.sampleIds = list(set(self.samples.flatten()))
+            self.nsamples = len(self.sampleIds)
         else:
             self.nfeatures = 1
             self.nsamples = len(self.labels)
 
     @staticmethod
-    def load(paramfile, classifymode, **opts):
-        return CLASSIFIERS[classifymode](paramfile, **opts)
+    def load(paramFile, classifyMode, **opts):
+        from thunder.utils.common import checkParams
+        checkParams(classifyMode.lower(), CLASSIFIERS.keys())
+        return CLASSIFIERS[classifyMode.lower()](paramFile, **opts)
 
-    def get(self, x, set=None):
+    def get(self, x, featureSet=None):
         pass
 
-    def fit(self, data, featureset=None):
+    def fit(self, data, featureSet=None):
         """
         Run classification on each record in a data set
 
@@ -101,17 +104,18 @@ class MassUnivariateClassifier(object):
         if self.nfeatures == 1:
             perf = data.rdd.mapValues(lambda x: [self.get(x)])
         else:
-            if featureset is None:
-                featureset = [[self.features[0]]]
-            for i in featureset:
+            if featureSet is None:
+                featureSet = [[self.features[0]]]
+            for i in featureSet:
                 assert array([item in i for item in self.features]).sum() != 0, "Feature set invalid"
-            perf = data.rdd.mapValues(lambda x: map(lambda i: self.get(x, i), featureset))
+            perf = data.rdd.mapValues(lambda x: asarray(map(lambda j: self.get(x, j), featureSet)))
 
-        return Series(perf, index='performance').__finalize__(data)
+        return Series(perf, index=featureSet).__finalize__(data)
 
 
 class GaussNaiveBayesClassifier(MassUnivariateClassifier):
-    """Classifier for Gaussian Naive Bayes classification.
+    """
+    Classifier for Gaussian Naive Bayes classification.
 
     Parameters
     ----------
@@ -126,11 +130,11 @@ class GaussNaiveBayesClassifier(MassUnivariateClassifier):
         MassUnivariateClassifier.__init__(self, paramfile)
         from sklearn.naive_bayes import GaussianNB
         from sklearn import cross_validation
-        self.cv_func = cross_validation.cross_val_score
+        self.cvFunc = cross_validation.cross_val_score
         self.cv = cv
         self.func = GaussianNB()
 
-    def get(self, x, featureset=None):
+    def get(self, x, featureSet=None):
         """
         Compute classification performance
 
@@ -153,13 +157,13 @@ class GaussNaiveBayesClassifier(MassUnivariateClassifier):
             X = zeros((self.nsamples, 1))
             X[:, 0] = x
         else:
-            X = zeros((self.nsamples, size(featureset)))
+            X = zeros((self.nsamples, size(featureSet)))
             for i in range(0, self.nsamples):
-                inds = (self.samples == self.sampleids[i]) & (in1d(self.features, featureset))
+                inds = (self.samples == self.sampleIds[i]) & (in1d(self.features, featureSet))
                 X[i, :] = x[inds]
 
         if self.cv > 0:
-            return self.cv_func(self.func, X, y, cv=self.cv).mean()
+            return self.cvFunc(self.func, X, y, cv=self.cv).mean()
         else:
             ypred = self.func.fit(X, y).predict(X)
             perf = array(y == ypred).mean()
@@ -186,7 +190,7 @@ class TTestClassifier(MassUnivariateClassifier):
         if unique != set((0, 1)):
             self.labels = array(map(lambda i: 0 if i == unique[0] else 1, self.labels))
 
-    def get(self, x, featureset=None):
+    def get(self, x, featureSet=None):
         """
         Compute classification performance as a t-statistic
 
@@ -204,21 +208,22 @@ class TTestClassifier(MassUnivariateClassifier):
             t-statistic for this record
         """
 
-        if (self.nfeatures > 1) & (size(featureset) > 1):
-            X = zeros((self.nsamples, size(featureset)))
-            for i in range(0, size(featureset)):
-                X[:, i] = x[self.features == featureset[i]]
+        if (self.nfeatures > 1) & (size(featureSet) > 1):
+            X = zeros((self.nsamples, size(featureSet)))
+            for i in range(0, size(featureSet)):
+                X[:, i] = x[self.features == featureSet[i]]
             t = float64(self.func(X[self.labels == 0, :], X[self.labels == 1, :])[0])
 
         else:
             if self.nfeatures > 1:
-                x = x[self.features == featureset]
+                x = x[self.features == featureSet]
             t = float64(self.func(x[self.labels == 0], x[self.labels == 1])[0])
 
         return t
 
 
+# keys should be all lowercase, access should call .lower()
 CLASSIFIERS = {
     'gaussnaivebayes': GaussNaiveBayesClassifier,
     'ttest': TTestClassifier
-}
\ No newline at end of file
+}
