@@ -16,8 +16,9 @@ class PCA(object):
     k : int
         Number of principal components to estimate
 
-    svdmethod : str, optional, default = "direct"
-        Which method to use for performing the SVD
+    svdMethod : str, optional, default = "auto"
+        Which method to use for performing the SVD. If set to 'auto',
+        will select preferred method based on dimensionality.
 
     Attributes
     ----------
@@ -35,12 +36,16 @@ class PCA(object):
     SVD : singular value decomposition
     """
 
-    def __init__(self, k=3, svdmethod='direct'):
+    def __init__(self, k=3, svdMethod='auto'):
         self.k = k
-        self.svdmethod = svdmethod
+        self.svdMethod = svdMethod
+        self.scores = None
+        self.latent = None
+        self.comps = None
 
     def fit(self, data):
-        """Estimate principal components
+        """
+        Estimate principal components
 
         Parameters
         ----------
@@ -56,9 +61,9 @@ class PCA(object):
         if type(data) is not RowMatrix:
             data = data.toRowMatrix()
 
-        mat = data.center(0)
+        mat = data.center(1)
 
-        svd = SVD(k=self.k, method=self.svdmethod)
+        svd = SVD(k=self.k, method=self.svdMethod)
         svd.calc(mat)
 
         self.scores = svd.u
@@ -68,7 +73,8 @@ class PCA(object):
         return self
 
     def transform(self, data):
-        """Project data into principal component space
+        """
+        Project data into principal component space
 
         Parameters
         ----------
@@ -89,6 +95,6 @@ class PCA(object):
         if type(data) is not RowMatrix:
             data = RowMatrix(data)
 
-        mat = data.center(0)
+        mat = data.center(1)
         scores = mat.times(self.comps.T / self.latent)
         return scores
