@@ -30,186 +30,182 @@ import urlparse
 from thunder.rdds.fileio.readers import _BotoS3Client, getByScheme
 
 
-_have_boto = False
+_haveBoto = False
 try:
     import boto
-    _have_boto = True
+    _haveBoto = True
 except ImportError:
     boto = None
 
 
 class LocalFSParallelWriter(object):
-    def __init__(self, datapath, overwrite=False):
-        self._datapath = datapath
+    def __init__(self, dataPath, overwrite=False, **kwargs):
+        self._dataPath = dataPath
         # thanks stack overflow:
         # http://stackoverflow.com/questions/5977576/is-there-a-convenient-way-to-map-a-file-uri-to-os-path
-        self._abspath = urllib.url2pathname(urlparse.urlparse(datapath).path)
+        self._absPath = urllib.url2pathname(urlparse.urlparse(dataPath).path)
         self._overwrite = overwrite
         self._checked = False
         self._checkDirectory()
 
     def _checkDirectory(self):
         if not self._checked:
-            if os.path.isfile(self._abspath):
+            if os.path.isfile(self._absPath):
                 raise ValueError("LocalFSParallelWriter must be initialized with path to directory not file" +
-                                 " in order to use writerFcn. Got: " + self._datapath)
-            if os.path.isdir(self._abspath):
+                                 " in order to use writerFcn. Got: " + self._dataPath)
+            if os.path.isdir(self._absPath):
                 if self._overwrite:
-                    shutil.rmtree(self._abspath)
+                    shutil.rmtree(self._absPath)
                 else:
-                    raise ValueError("Directory %s already exists, and overwrite is false" % self._datapath)
-            os.mkdir(self._abspath)
+                    raise ValueError("Directory %s already exists, and overwrite is false" % self._dataPath)
+            os.mkdir(self._absPath)
             self._checked = True
 
     def writerFcn(self, kv):
         label, buf = kv
-        with open(os.path.join(self._abspath, label), 'wb') as f:
+        with open(os.path.join(self._absPath, label), 'wb') as f:
             f.write(buf)
 
 
 class _BotoS3Writer(_BotoS3Client):
-    def __init__(self):
-        super(_BotoS3Writer, self).__init__()
-
-        self._contextactive = False
+    def __init__(self, awsCredentialsOverride=None):
+        super(_BotoS3Writer, self).__init__(awsCredentialsOverride=awsCredentialsOverride)
+        self._contextActive = False
         self._conn = None
-        self._keyname = None
+        self._keyName = None
         self._bucket = None
 
-    def activateContext(self, datapath, isDirectory):
+    def activateContext(self, dataPath, isDirectory):
         """
         Set up a boto s3 connection.
 
-        This is expected to end up being called once for each spark worker.
         """
-        conn = boto.connect_s3()
-        parsed = _BotoS3Client.parseS3Query(datapath)
-        bucketname = parsed[0]
-        keyname = parsed[1]
-        if isDirectory and (not keyname.endswith("/")):
-            keyname += "/"
-        bucket = conn.get_bucket(bucketname)
+        conn = boto.connect_s3(**self.awsCredentialsOverride.credentialsAsDict)
+        parsed = _BotoS3Client.parseS3Query(dataPath)
+        bucketName = parsed[0]
+        keyName = parsed[1]
+        if isDirectory and (not keyName.endswith("/")):
+            keyName += "/"
+        bucket = conn.get_bucket(bucketName)
 
         self._conn = conn
-        self._keyname = keyname
+        self._keyName = keyName
         self._bucket = bucket
-        self._contextactive = True
+        self._contextActive = True
 
     @property
     def bucket(self):
         return self._bucket
 
     @property
-    def keyname(self):
-        return self._keyname
+    def keyName(self):
+        return self._keyName
 
     @property
     def contextActive(self):
-        return self._contextactive
+        return self._contextActive
 
 
 class BotoS3ParallelWriter(_BotoS3Writer):
-    # todo: needs to check before writing if overwrite is True
-    def __init__(self, datapath, overwrite=False):
-        super(BotoS3ParallelWriter, self).__init__()
-        self._datapath = datapath
+    def __init__(self, dataPath, overwrite=False, awsCredentialsOverride=None):
+        super(BotoS3ParallelWriter, self).__init__(awsCredentialsOverride=awsCredentialsOverride)
+        self._dataPath = dataPath
         self._overwrite = overwrite
 
     def writerFcn(self, kv):
         if not self.contextActive:
-            self.activateContext(self._datapath, True)
+            self.activateContext(self._dataPath, True)
 
         label, buf = kv
         s3key = boto.s3.key.Key(self.bucket)
-        s3key.name = self.keyname + label
+        s3key.name = self.keyName + label
         s3key.set_contents_from_string(buf)
 
 
 class LocalFSFileWriter(object):
-    def __init__(self, datapath, filename, overwrite=False):
-        self._datapath = datapath
+    def __init__(self, dataPath, filename, overwrite=False, **kwargs):
+        self._dataPath = dataPath
         self._filename = filename
-        self._abspath = os.path.join(urllib.url2pathname(urlparse.urlparse(datapath).path), filename)
+        self._absPath = os.path.join(urllib.url2pathname(urlparse.urlparse(dataPath).path), filename)
         self._overwrite = overwrite
         self._checked = False
 
     def _checkWriteFile(self):
         if not self._checked:
-            if os.path.isdir(self._abspath):
+            if os.path.isdir(self._absPath):
                 raise ValueError("LocalFSFileWriter must be initialized with path to file, not directory," +
                                  " in order to use writeFile. Got path: '%s', filename: '%s'" %
-                                 (self._datapath, self._filename))
-            if (not self._overwrite) and os.path.exists(self._abspath):
-                raise ValueError("File %s already exists, and overwrite is false" % self._datapath)
+                                 (self._dataPath, self._filename))
+            if (not self._overwrite) and os.path.exists(self._absPath):
+                raise ValueError("File %s already exists, and overwrite is false" % self._dataPath)
             self._checked = True
 
     def writeFile(self, buf):
         self._checkWriteFile()
-        with open(os.path.join(self._abspath), 'wb') as f:
+        with open(os.path.join(self._absPath), 'wb') as f:
             f.write(buf)
 
 
 class BotoS3FileWriter(_BotoS3Writer):
-    # todo: needs to check before writing if overwrite is True
-    def __init__(self, datapath, filename, overwrite=False):
-        super(BotoS3FileWriter, self).__init__()
-        self._datapath = datapath
+    def __init__(self, dataPath, filename, overwrite=False, awsCredentialsOverride=None):
+        super(BotoS3FileWriter, self).__init__(awsCredentialsOverride=awsCredentialsOverride)
+        self._dataPath = dataPath
         self._filename = filename
         self._overwrite = overwrite
 
     def writeFile(self, buf):
         if not self.contextActive:
-            self.activateContext(self._datapath, True)
+            self.activateContext(self._dataPath, True)
 
-        s3key = boto.s3.key.Key(self.bucket)
-        s3key.name = self.keyname + self._filename
-        s3key.set_contents_from_string(buf)
+        s3Key = boto.s3.key.Key(self.bucket)
+        s3Key.name = self.keyName + self._filename
+        s3Key.set_contents_from_string(buf)
 
 
 class LocalFSCollectedFileWriter(object):
-    def __init__(self, datapath, overwrite=False):
-        self._datapath = datapath
-        self._abspath = urllib.url2pathname(urlparse.urlparse(datapath).path)
+    def __init__(self, dataPath, overwrite=False, **kwargs):
+        self._dataPath = dataPath
+        self._absPath = urllib.url2pathname(urlparse.urlparse(dataPath).path)
         self._overwrite = overwrite
         self._checked = False
 
     def _checkDirectory(self):
         # todo: this is duplicated code with LocalFSParallelWriter
         if not self._checked:
-            if os.path.isfile(self._abspath):
+            if os.path.isfile(self._absPath):
                 raise ValueError("LocalFSCollectedFileWriter must be initialized with path to directory not file" +
-                                 " in order to use writerFcn. Got: " + self._datapath)
-            if os.path.isdir(self._abspath):
+                                 " in order to use writerFcn. Got: " + self._dataPath)
+            if os.path.isdir(self._absPath):
                 if self._overwrite:
-                    shutil.rmtree(self._abspath)
+                    shutil.rmtree(self._absPath)
                 else:
-                    raise ValueError("Directory %s already exists, and overwrite is false" % self._datapath)
-            os.mkdir(self._abspath)  # will throw error if is already a file
+                    raise ValueError("Directory %s already exists, and overwrite is false" % self._dataPath)
+            os.mkdir(self._absPath)  # will throw error if is already a file
             self._checked = True
 
     def writeCollectedFiles(self, labelBufSequence):
         self._checkDirectory()
         for filename, buf in labelBufSequence:
-            abspath = os.path.join(self._abspath, filename)
-            with open(abspath, 'wb') as f:
+            absPath = os.path.join(self._absPath, filename)
+            with open(absPath, 'wb') as f:
                 f.write(buf)
 
 
 class BotoS3CollectedFileWriter(_BotoS3Writer):
     # todo: needs to check before writing if overwrite is True
-    def __init__(self, datapath, overwrite=False):
-        super(BotoS3CollectedFileWriter, self).__init__()
-        self._datapath = datapath
+    def __init__(self, dataPath, overwrite=False, awsCredentialsOverride=None):
+        super(BotoS3CollectedFileWriter, self).__init__(awsCredentialsOverride=awsCredentialsOverride)
+        self._dataPath = dataPath
         self._overwrite = overwrite
 
     def writeCollectedFiles(self, labelBufSequence):
         if not self.contextActive:
-            self.activateContext(self._datapath, True)
+            self.activateContext(self._dataPath, True)
 
         for filename, buf in labelBufSequence:
-            s3key = boto.s3.key.Key(self.bucket)
-            s3key.name = self.keyname + filename
-            s3key.set_contents_from_string(buf)
+            s3Key = boto.s3.key.Key(self.bucket)
+            s3Key.name = self.keyName + filename
+            s3Key.set_contents_from_string(buf)
 
 
 SCHEMAS_TO_PARALLELWRITERS = {
@@ -235,7 +231,6 @@ SCHEMAS_TO_FILEWRITERS = {
 }
 
 SCHEMAS_TO_COLLECTEDFILEWRITERS = {
-
     '': LocalFSCollectedFileWriter,
     'file': LocalFSCollectedFileWriter,
     's3': BotoS3CollectedFileWriter,
@@ -247,7 +242,7 @@ SCHEMAS_TO_COLLECTEDFILEWRITERS = {
 }
 
 
-def getParallelWriterForPath(datapath):
+def getParallelWriterForPath(dataPath):
     """Returns the class of a parallel file writer suitable for the scheme used by `datapath`.
 
     The resulting class object must still be instantiated in order to get a usable instance of the class.
@@ -255,10 +250,10 @@ def getParallelWriterForPath(datapath):
     Throws NotImplementedError if the requested scheme is explicitly not supported (e.g. "ftp://").
     Returns LocalFSParallelWriter if scheme is absent or not recognized.
     """
-    return getByScheme(datapath, SCHEMAS_TO_PARALLELWRITERS, LocalFSParallelWriter)
+    return getByScheme(dataPath, SCHEMAS_TO_PARALLELWRITERS, LocalFSParallelWriter)
 
 
-def getFileWriterForPath(datapath):
+def getFileWriterForPath(dataPath):
     """Returns the class of a file writer suitable for the scheme used by `datapath`.
 
     The resulting class object must still be instantiated in order to get a usable instance of the class.
@@ -266,10 +261,10 @@ def getFileWriterForPath(datapath):
     Throws NotImplementedError if the requested scheme is explicitly not supported (e.g. "ftp://").
     Returns LocalFSFileWriter if scheme is absent or not recognized.
     """
-    return getByScheme(datapath, SCHEMAS_TO_FILEWRITERS, LocalFSFileWriter)
+    return getByScheme(dataPath, SCHEMAS_TO_FILEWRITERS, LocalFSFileWriter)
 
 
-def getCollectedFileWriterForPath(datapath):
+def getCollectedFileWriterForPath(dataPath):
     """Returns the class of a collected file writer suitable for the scheme used by `datapath`.
 
     The resulting class object must still be instantiated in order to get a usable instance of the class.
@@ -277,4 +272,4 @@ def getCollectedFileWriterForPath(datapath):
     Throws NotImplementedError if the requested scheme is explicitly not supported (e.g. "ftp://").
     Returns LocalFSCollectedFileWriter if scheme is absent or not recognized.
     """
-    return getByScheme(datapath, SCHEMAS_TO_COLLECTEDFILEWRITERS, LocalFSCollectedFileWriter)
\ No newline at end of file
+    return getByScheme(dataPath, SCHEMAS_TO_COLLECTEDFILEWRITERS, LocalFSCollectedFileWriter)
\ No newline at end of file
