@@ -44,22 +44,42 @@ class SpatialSeries(Series):
             """Create a list of key value pairs with multiple shifted copies
             of each record over a region specified by sz
             """
-            rng_x = range(-sz, sz+1, 1)
-            rng_y = range(-sz, sz+1, 1)
+            import itertools
+            xrng = range(-sz, sz+1, 1)
+            yrng = range(-sz, sz+1, 1)
             out = list()
-            for x in rng_x:
-                for y in rng_y:
-                    new_x = clip(ind[0] + x, mn[0], mx[0])
-                    new_y = clip(ind[1] + y, mn[1], mx[1])
-                    newind = (new_x, new_y, ind[2])
-                    out.append((newind, v))
+            # build list of pairs with new indices and the value
+            for x, y in itertools.product(xrng, yrng):
+                xnew = clip(ind[0] + x, mn[0], mx[0])
+                ynew = clip(ind[1] + y, mn[1], mx[1])
+                key = (xnew, ynew)
+                out.append((key, v))
+            # append third index if present
+            if len(ind) > 2:
+                out = map(lambda (k, v): ((k[0], k[1], ind[2]), v), out)
             return out
+
         dims = self.dims
         rdd = self.rdd.flatMap(lambda (k, v): toNeighbors(k, v, neighborhood, dims.min[0:2], dims.max[0:2]))
 
         return self._constructor(rdd).__finalize__(self)
 
     def localCorr(self, neighborhood):
+        """
+        Correlate every signal to the average of its local neighborhood.
+
+        This algorithm computes, for every spatial record, the correlation coefficient
+        between that record's series, and the average series of all records within
+        a local neighborhood with a size defined by the neighborhood parameter.
+        For data with three spatial keys, only neighborhoods in x and y
+        currently supported.
+
+        Parameters
+        ----------
+        neighborhood : integer
+            Size of neighborhood, describes extent in either direction, so
+            total neighborhood will be 2n + 1.
+        """
 
         if len(self.dims.max) not in [2, 3]:
                 raise NotImplementedError('keys must have 2 or 3 dimensions to compute local correlations')
@@ -76,6 +96,5 @@ class SpatialSeries(Series):
         # get correlations
         corr = result.mapValues(lambda x: corrcoef(x[0], x[1])[0, 1])
 
-        # force sorting, but reverse keys for correct ordering
-        output = corr.map(lambda (k, v): (k[::-1], v)).sortByKey().map(lambda (k, v): (k[::-1], v))
-        return Series(output, index='correlation').__finalize__(self)
\ No newline at end of file
+        # sort output because we expect shuffling to change ordering
+        return Series(corr, index='correlation').__finalize__(self).sortByKey()
\ No newline at end of file
